@@ -1,3 +1,5 @@
+import os
+import sys
 from pathlib import Path
 from typing import Optional
 
@@ -20,7 +22,10 @@ def _read_csv(
 
 
 def _to_numeric(value):
-    return pandas.to_numeric(value, errors="ignore")
+    try:
+        return float(value)
+    except ValueError:
+        return value
 
 
 def _do_not_anything(value):
@@ -43,6 +48,7 @@ def _to_excel(
     workbook.save(xlsx_file)
 
 
+
 @click.command(name="csv2xlsx", help="Convert csv file to xlsx file.")
 @click.argument("csv_file")
 @click.argument("xlsx_file", required=False)
@@ -63,7 +69,7 @@ def _to_excel(
     "--string_to_numeric",
     type=bool,
     default=True,
-    help="If true, convert string to numeric. [default: utf-8]",
+    help="If true, convert string to numeric. [default: true]",
 )
 def csv2xlsx(
     csv_file: str,
@@ -73,9 +79,14 @@ def csv2xlsx(
     quotechar: Optional[str],
     string_to_numeric: bool,
 ):
+    if not os.path.exists(csv_file):
+        print(f"No such file or directory: '{csv_file}'", file=sys.stderr)
+        sys.exit(1)
+
     df = _read_csv(csv_file, sep=sep, encoding=encoding, quotechar=quotechar)
     if xlsx_file is None:
         csv_file_path = Path(csv_file)
         xlsx_file_name = f"{csv_file_path.stem}.xlsx"
         xlsx_file = str(csv_file_path.parent / xlsx_file_name)
+
     _to_excel(df=df, xlsx_file=xlsx_file, string_to_numeric=string_to_numeric)
